@@ -103,6 +103,8 @@ private slots:
     void on_buttonRunParted_clicked();
     void on_viewServicesButton_clicked();
 
+    void on_diskCombo_currentIndexChanged(int);
+    void on_sliderPart_sliderPressed();
     void on_sliderPart_valueChanged(int value);
     void on_checkBoxEncryptAuto_toggled(bool checked);
     void on_customPartButton_clicked(bool checked);
@@ -135,7 +137,7 @@ private:
 
     // command line options
     bool brave, pretend, automatic, nocopy, sync;
-    bool oem, oobe;
+    bool oem, oobe, mountkeep;
     // configuration management
     MSettings *config = nullptr;
     enum ConfigAction { ConfigSave, ConfigLoadA, ConfigLoadB };
@@ -143,6 +145,7 @@ private:
     bool uefi = false;
     bool mactest = false;
     bool containsSystemD = false;
+    bool containsRunit = false;
     bool isRemasteredDemoPresent = false;
 
     // source medium
@@ -203,9 +206,6 @@ private:
     void stashServices(bool save);
     void stashAdvancedFDE(bool save);
     int selectTimeZone(const QString &zone);
-    void clearpartitiontables(const QString &dev);
-    bool checkForSnapshot();
-    bool checkForRemaster();
     void rsynchomefolder(const QString dpath);
     void changeRemasterdemoToNewUser(const QString dpath);
     void resetBlueman();
