@@ -32,12 +32,12 @@ class PartMan : public QObject
 {
     Q_OBJECT
     enum TreeColumns {
-        Device,
-        Size,
-        Label,
+        Device, // Data: destination mapped device (encryption)
+        Size, // Data: size of existing device (bytes)
+        Label, // Text: existing label (not QLineEdit text)
         UseFor,
         Encrypt,
-        Format,
+        Format, // Text: existing format (not QLineEdit text)
         Options
     };
     MProcess &proc;
@@ -53,6 +53,7 @@ class PartMan : public QObject
     void setupItem(QTreeWidgetItem *twit, const BlockDeviceInfo *bdinfo,
         int defaultMB = 0, const QString &defaultUse = QString());
     void labelParts(QTreeWidgetItem *drive);
+    void resizeColumnsToFit();
     static QString translateUse(const QString &alias);
     static QString describeUse(const QString &use);
     void clearPartitionTables(const QString &dev);
@@ -61,11 +62,13 @@ class PartMan : public QObject
         enum Qt::CheckState state, QTreeWidgetItem *exclude);
     bool calculatePartBD();
     inline void drvitMarkLayout(QTreeWidgetItem *drvit, const bool old);
+    inline bool drvitIsMapperList(const QTreeWidgetItem *drvit) const;
     inline bool twitIsOldLayout(const QTreeWidgetItem *twit, const bool chkUp=true) const;
     inline long long twitSize(QTreeWidgetItem *twit, bool bytes=false);
     inline bool twitWillFormat(QTreeWidgetItem *twit);
     inline QString twitUseFor(QTreeWidgetItem *twit);
-    inline bool twitIsMapped(const QTreeWidgetItem * twit);
+    inline bool twitIsMapped(const QTreeWidgetItem *twit) const;
+    inline bool twitWillMap(const QTreeWidgetItem *twit) const;
     inline QString twitMappedDevice(const QTreeWidgetItem *twit, const bool full=false) const;
     inline QComboBox *twitComboBox(QTreeWidgetItem  *twit, int column);
     inline QLineEdit *twitLineEdit(QTreeWidgetItem  *twit, int column);
@@ -78,7 +81,7 @@ class PartMan : public QObject
     void partClearClick(bool);
     void partAddClick(bool);
     void partRemoveClick(bool);
-    void partDefaultClick(bool);
+    bool eventFilter(QObject *object, QEvent *event);
 public:
     bool gptoverride=false, uefi=false, brave=false;
     long long rootSpaceNeeded = 0;
@@ -102,7 +105,7 @@ public:
     bool fixCryptoSetup(const QString &keyfile, bool isNewKey);
     bool makeFstab(bool populateMediaMounts);
     bool mountPartitions();
-    void unmount(bool all = false);
+    void unmount();
     bool willFormat(const QString &point);
     QString getMountDev(const QString &point, const bool mapped=true);
     int swapCount();
